==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cellar/dialogs_bg.lua <==
dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Вече знаете правилата. Сега можете да ги упражните. От време на време ще Ви даваме съвети.")

dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Сега не трябва да плувам надолу. А и нагоре не мога.")

dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("Ей, подреди ги малко там горе. И внимавай!")

dialogId("pra-m-nepohnu", "font_small", "I can’t move this. This is steel.")
dialogStr("Това не мога да го преместя. Стоманено е.")

dialogId("pra-m-zpatky", "font_small", "Come back, you can’t go further!")
dialogStr("Върни се, не можеш да продължиш напред!")

dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Хм... това е сложно. Ако избутаме меда ще бъдем размазани под консервата с кайсиево сладко.")

dialogId("pra-m-vyrazit", "font_small", "Couldn’t we push it aside with that axe?")
dialogStr("Не може ли да го избутаме настрани с брадвичката?")

dialogId("pra-v-dobrynapad", "font_big", "That’s a good idea.")
dialogStr("Това е добра идея.")

dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Сега на мога да взема брадвичката. Консервата пречи.")

dialogId("pra-v-vzit", "font_big", "You mustn’t push the axe!")
dialogStr("Не бива да буташ брадвичката!")

dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I’ll shove the axe on it and everything will be okay.")
dialogStr("Ако можеш да бутнеш онази консерва към мен ще плъзна брадвичката по нея и всичко ще е наред.")

dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Ако решите част от ребуса можете да запишете позицията.")

dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Но само ако сте сигурни в решението.")

dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Запомнете какво казахме за записването на позицията.")

dialogId("pra-m-uvazovat", "font_small", "I shouldn’t be thinking about this.")
dialogStr("Не трябва дори да си го помислям.")

dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Положението не изглежда розово. Ще трябва да рестартирате нивото.")

dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Ако пуснеш това докато съм тук, никога няма да изляза.")

dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Застанала си ми на пътя. Опитай да се скриеш някъде другаде.")

dialogId("pra-m-strach", "font_small", "Here? I’m little bit afraid. Will I get out?")
dialogStr("Тук? Малко ме е страх. Дали ще изляза някога?")

dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Почакай и ще видиш.")

dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("Тук ще Ви дадем съвет. Трябва да поставите онази книга там горе отляво.")

dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("Така, че да подпре онзи стоманен цилиндър когато го бутна.")

dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Обаче няма да Ви кажем как да го направите.")

dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other’s back, we can push them down or onto some solid structure.")
dialogStr("Само помнете: въпреки, че не можем да плъзгаме обекти по гърба на другия, можем да ги избутваме да паднат или да ги плъзгаме по някакъв друг обект или структура.")

dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Дали да мина отгоре?")

dialogId("pra-m-neradit", "font_small", "Shhhh. That’s too many hints.")
dialogStr("Шшшт. Много съвети станаха.")

dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Стават такива работи.")

dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Понякога трябва да се мисли мнооого напред.")

dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("И често тогава се налага да се рестартира нивото.")

dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("Признаваме, че го направихме нарочно.")

dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("За да можете да опитате отново - този път без съвети.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/cellar/dialogs_bg.lua <==
dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Вече знаете правилата. Сега можете да ги упражните. От време на време ще Ви даваме съвети.")

dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Сега не трябва да плувам надолу. А и нагоре не мога.")

dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("Ей, подреди ги малко там горе. И внимавай!")

dialogId("pra-m-nepohnu", "font_small", "I can’t move this. This is steel.")
dialogStr("Това не мога да го преместя. Стоманено е.")

dialogId("pra-m-zpatky", "font_small", "Come back, you can’t go further!")
dialogStr("Върни се, не можеш да продължиш напред!")

dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Хм... това е сложно. Ако избутаме меда ще бъдем размазани под буркана с кайсиево сладко.")

dialogId("pra-m-vyrazit", "font_small", "Couldn’t we push it aside with that axe?")
dialogStr("Не може ли да го избутаме настрани с брадвичката?")

dialogId("pra-v-dobrynapad", "font_big", "That’s a good idea.")
dialogStr("Това е добра идея.")

dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Сега на мога да взема брадвичката. Бурканът пречи.")

dialogId("pra-v-vzit", "font_big", "You mustn’t push the axe!")
dialogStr("Не бива да буташ брадвичката!")

dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I’ll shove the axe on it and everything will be okay.")
dialogStr("Ако можеш да бутнеш онзи буркан към мен ще плъзна брадвичката по нея и всичко ще е наред.")

dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Ако решите част от ребуса можете да запишете позицията.")

dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Но само ако сте сигурни в решението.")

dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Запомнете какво казахме за записването на позицията.")

dialogId("pra-m-uvazovat", "font_small", "I shouldn’t be thinking about this.")
dialogStr("Не трябва дори да си го помислям.")

dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Положението не изглежда розово. Ще трябва да рестартирате нивото.")

dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Ако пуснеш това докато съм тук, никога няма да изляза.")

dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Застанала си ми на пътя. Опитай да се скриеш другаде.")

dialogId("pra-m-strach", "font_small", "Here? I’m little bit afraid. Will I get out?")
dialogStr("Тук? Малко ме е страх. Дали ще изляза някога?")

dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Почакай и ще видиш.")

dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("Тук ще Ви дадем съвет. Трябва да поставите онази книга там горе отляво.")

dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("Така, че да подпре онзи стоманен цилиндър когато го бутна.")

dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Обаче няма да Ви кажем как да го направите.")

dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other’s back, we can push them down or onto some solid structure.")
dialogStr("Само помнете: въпреки, че не можем да плъзгаме обекти по гърба на другия, можем да ги избутваме да паднат или да ги плъзгаме по някакъв друг обект или структура.")

dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Дали да мина отгоре?")

dialogId("pra-m-neradit", "font_small", "Shhhh. That’s too many hints.")
dialogStr("Шшшт. Много съвети станаха.")

dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Стават такива работи.")

dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Понякога трябва да се мисли мно-о-ого напред.")

dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("И често тогава се налага да се рестартира нивото.")

dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("Признаваме, че го направихме нарочно.")

dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("За да можете да опитате отново - този път без съвети.")
